@@ -2,12 +2,9 @@ package Set::CrossProduct;
 use strict;
 
 use warnings;
-no warnings;
+use warnings::register;
 
-use subs qw();
-use vars qw( $VERSION );
-
-$VERSION = '2.004';
+our $VERSION = '2.005';
 
 =encoding utf8
 
@@ -145,7 +142,9 @@ code. Of course, your use is probably more interesting. :)
 =item * new( { LABEL => [ ... ], LABEL2 => [ ... ] } )
 
 Given arrays that represent some sets, return a C<Set::CrossProduct>
-instance that represents the cross product of those sets.
+instance that represents the cross product of those sets. If you don't
+provide at least two sets, C<new> returns undef and will emit a warning
+if warnings are enabled.
 
 You can create the sets in two different ways: unlabeled and labeled sets.
 
@@ -207,13 +206,18 @@ sub new {
 		$self->{arrays}  = $constructor_ref;
 		}
 	else {
+		warnings::warn( "Set::Crossproduct->new takes an array or hash reference" ) if warnings::enabled();
 		return;
 		}
 
 	my $array_ref = $self->{arrays};
-	return unless @$array_ref > 1;
+	unless( @$array_ref > 1 ) {
+		warnings::warn( "You need at least two sets for Set::CrossProduct to work" ) if warnings::enabled();
+		return;
+		}
 
 	foreach my $array ( @$array_ref ) {
+		warnings::warn( "Each array element or hash value needs to be an array reference" ) if warnings::enabled();
 		return unless ref $array eq ref [];
 		}
 
